<?php
namespace PME\Controllers\Parametrizacao;

use Zeedhi\Framework\DTO;
use Zeedhi\Framework\DTO\Response\Error;

class ValoresReferenciaDiario extends \PME\Services\TeknisaCrud {
    protected $crudService;
	protected $parameterBag;
	protected $connection;
	protected $environment;
	protected $newCode;
    
    public function __construct($crudService, $parameterBag, $connection, $environment, $newCode) {
        parent::__construct($crudService, $parameterBag);
        $this->connection = $connection;
        $this->environment = $environment;
        $this->newCode     = $newCode;
    }
    
    public function exportValRef(DTO\Request $request, DTO\Response $response) {
        $this->connection->beginTransaction();
        try {
            $row = $request->getRow();
            $nrorg = $this->environment->getNrOrg();
            $row['NRORG'] = $nrorg;
            $this->deleteExportValRef($row);
            $this->insertExportValRef($row);
            
            $this->connection->commit();
        } catch (\Exception $e) {
            $this->connection->rollback();
			$response->setError(new Error($e->getMessage(), 500));
		}
    }
    
    private function deleteExportValRef($row) {
        $deleteMicro = "DELETE FROM REFDIARIOMICRO WHERE CDFILCENTPME = :CDFILCENTPME_DEST AND (INSTR(:CDTIPOCARD_DEST, CDTIPOCARD) > 0 OR (:CDTIPOCARD_DEST = 'T'))
        AND NRVALREFDIARIO IN (SELECT NRVALREFDIARIO FROM VALREFDIARIO WHERE CDFILCENTPME = :CDFILCENTPME_DEST AND (INSTR(:CDTIPOCARD_DEST, CDTIPOCARD) > 0 OR (:CDTIPOCARD_DEST = 'T')))";
        $params = array(
            'CDFILCENTPME_DEST' => $row['CDFILCENTPME'],
            'CDTIPOCARD_DEST' => $row['CDTIPOCARD'],
        );
        $stdMicro = $this->connection->prepare($deleteMicro);
        $stdMicro->execute($params);
        
        $deleteMacro = "DELETE FROM VALREFDIARIO WHERE CDFILCENTPME = :CDFILCENTPME_DEST AND (INSTR(:CDTIPOCARD_DEST, CDTIPOCARD) > 0 OR (:CDTIPOCARD_DEST = 'T'))";
        $stdMacro = $this->connection->prepare($deleteMacro);
        $stdMacro->execute($params);
    }
    
    private function insertExportValRef($row) {
        $nrvalRef = implode('_', array_column($row['selectedRows'], 'NRVALREFDIARIO'));
        $insertExport = "INSERT INTO VALREFDIARIO(NRVALREFDIARIO, CDFILCENTPME, CDTIPOCARD, PERCNECDIARIA, NRREFEICAO, VRENERGIA, VRCARBVETMIN, VRCARBVETMAX, VRCARBENERMIN, VRCARBENERMAX, VRPROTVETMIN, VRPROTVETMAX, VRPROTENERMIN, VRPROTENERMAX, VRLIPVETMIN, VRLIPVETMAX, VRLIPENERMIN, VRLIPENERMAX, DSFONTE)
            SELECT NRVALREFDIARIO, TPC.CDFILCENTPME, TPC.CDTIPOCARD, PERCNECDIARIA, NRREFEICAO, VRENERGIA, VRCARBVETMIN, VRCARBVETMAX, VRCARBENERMIN, VRCARBENERMAX, VRPROTVETMIN, VRPROTVETMAX, VRPROTENERMIN, VRPROTENERMAX, VRLIPVETMIN, VRLIPVETMAX, VRLIPENERMIN, VRLIPENERMAX, DSFONTE 
            FROM VALREFDIARIO V JOIN TIPOCARD TPC ON TPC.CDFILCENTPME = :CDFILCENTPME_DEST AND (INSTR(:CDTIPOCARD_DEST, TPC.CDTIPOCARD) > 0 OR (:CDTIPOCARD_DEST = 'T'))
            WHERE V.CDTIPOCARD = :CDTIPOCARD_ORIG AND V.CDFILCENTPME = :CDFILCENTPME_ORIG AND INSTR(:NRVALREFDIARIO, NRVALREFDIARIO) > 0";
        $params = array(
            "CDFILCENTPME_ORIG" => $row['CDFILCENTPME_ORIG'],
            "CDTIPOCARD_ORIG"   => $row['CDTIPOCARD_ORIG'],
            "CDFILCENTPME_DEST" => $row['CDFILCENTPME'],
            "CDTIPOCARD_DEST"   => $row['CDTIPOCARD'],
            "NRVALREFDIARIO" => $nrvalRef,
        );
        $stmt = $this->connection->prepare($insertExport);
        $stmt->execute($params);
        
        $for = "BEGIN FOR VALREF IN (SELECT NRVALREFDIARIO, TPC.CDFILCENTPME, TPC.CDTIPOCARD 
                        FROM VALREFDIARIO V JOIN TIPOCARD TPC ON TPC.CDFILCENTPME = :CDFILCENTPME_DEST AND (INSTR(:CDTIPOCARD_DEST, TPC.CDTIPOCARD) > 0 OR (:CDTIPOCARD_DEST = 'T'))
                        WHERE V.CDTIPOCARD = :CDTIPOCARD_ORIG AND V.CDFILCENTPME = :CDFILCENTPME_ORIG AND INSTR(:NRVALREFDIARIO, NRVALREFDIARIO) > 0) LOOP
                    INSERT INTO REFDIARIOMICRO(NRREFDIARIOMICRO, NRVALREFDIARIO, CDFILCENTPME, CDTIPOCARD, CDNUTRIENTE, VRENERGIA)
                    SELECT NRREFDIARIOMICRO, VALREF.NRVALREFDIARIO, VALREF.CDFILCENTPME, VALREF.CDTIPOCARD, CDNUTRIENTE, VRENERGIA FROM REFDIARIOMICRO
                        WHERE CDFILCENTPME = VALREF.CDFILCENTPME AND CDTIPOCARD = VALREF.CDTIPOCARD AND NRVALREFDIARIO = VALREF.NRVALREFDIARIO;
                END LOOP;
                END;";
        $stmt2 = $this->connection->prepare($for);
        $stmt2->execute($params);
    }
}